==> pointblank_0.6.0.tar.gz: pointblank/R/reexports.R <==
#
#                _         _    _      _                _    
#               (_)       | |  | |    | |              | |   
#  _ __    ___   _  _ __  | |_ | |__  | |  __ _  _ __  | | __
# | '_ \  / _ \ | || '_ \ | __|| '_ \ | | / _` || '_ \ | |/ /
# | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   < 
# | .__/  \___/ |_||_| |_| \__||_.__/ |_| \__,_||_| |_||_|\_\
# | |                                                        
# |_|                                                        
# 
# This file is part of the 'rich-iannone/pointblank' package.
# 
# (c) Richard Iannone <riannone@me.com>
# 
# For full copyright and license information, please look at
# https://rich-iannone.github.io/pointblank/LICENSE.html
#


#' @importFrom dplyr vars
#' @export
dplyr::vars

#' @importFrom dplyr case_when
#' @export
dplyr::case_when

#' @importFrom dplyr between
#' @export
dplyr::between

#' @importFrom dplyr expr
#' @export
dplyr::expr

#' @importFrom tidyselect starts_with
#' @export
tidyselect::starts_with

#' @importFrom tidyselect ends_with
#' @export
tidyselect::ends_with

#' @importFrom tidyselect contains
#' @export
tidyselect::contains

#' @importFrom tidyselect matches
#' @export
tidyselect::matches

#' @importFrom tidyselect everything
#' @export
tidyselect::everything

#' @importFrom blastula creds
#' @export
blastula::creds

#' @importFrom blastula creds_anonymous
#' @export
blastula::creds_anonymous

#' @importFrom blastula creds_key
#' @export
blastula::creds_key

#' @importFrom blastula creds_file
#' @export
blastula::creds_file

==> pointblank_0.11.0.tar.gz: pointblank/R/reexports.R <==
#
#                _         _    _      _                _    
#               (_)       | |  | |    | |              | |   
#  _ __    ___   _  _ __  | |_ | |__  | |  __ _  _ __  | | __
# | '_ \  / _ \ | || '_ \ | __|| '_ \ | | / _` || '_ \ | |/ /
# | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   < 
# | .__/  \___/ |_||_| |_| \__||_.__/ |_| \__,_||_| |_||_|\_\
# | |                                                        
# |_|                                                        
# 
# This file is part of the 'rich-iannone/pointblank' package.
# 
# (c) Richard Iannone <riannone@me.com>
# 
# For full copyright and license information, please look at
# https://rich-iannone.github.io/pointblank/LICENSE.html
#


#' @importFrom dplyr vars
#' @export
dplyr::vars

#' @importFrom dplyr case_when
#' @export
dplyr::case_when

#' @importFrom dplyr between
#' @export
dplyr::between

#' @importFrom rlang expr
#' @export
rlang::expr

#' @importFrom tidyselect starts_with
#' @export
tidyselect::starts_with

#' @importFrom tidyselect ends_with
#' @export
tidyselect::ends_with

#' @importFrom tidyselect contains
#' @export
tidyselect::contains

#' @importFrom tidyselect matches
#' @export
tidyselect::matches

#' @importFrom tidyselect everything
#' @export
tidyselect::everything

#' @importFrom blastula creds
#' @export
blastula::creds

#' @importFrom blastula creds_anonymous
#' @export
blastula::creds_anonymous

#' @importFrom blastula creds_key
#' @export
blastula::creds_key

#' @importFrom blastula creds_file
#' @export
blastula::creds_file
